"use strict";
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.
Object.defineProperty(exports, "__esModule", { value: true });
var errors_1 = require("./errors");
var utilities_1 = require("./utilities");
// Re-export custom errors.
var errors_2 = require("./errors");
exports.ConfigNotFound = errors_2.ConfigNotFound;
/** A configuration file loader. */
var Disposition = /** @class */ (function () {
    function Disposition(moduleName, options) {
        this.moduleName = moduleName;
        this.options = options;
        this.filenames = [
            this.moduleName + ".config.js",
            this.moduleName + ".config.ts",
            this.moduleName + ".config.tsx",
        ];
    }
    /**
     * Search for and load the configuation file.
     *
     * @param directory The directory to start searching from. Defaults
     *                  to the current working directory.
     */
    Disposition.prototype.load = function (directory) {
        if (directory === void 0) { directory = process.cwd(); }
        var configPath = utilities_1.find(directory, this.filenames);
        if (configPath === undefined) {
            throw new errors_1.ConfigNotFound(this.filenames);
        }
        if (this.options !== undefined && this.options.project !== undefined) {
            return _load(configPath, this.options.project);
        }
        return _load(configPath);
    };
    return Disposition;
}());
exports.default = Disposition;
/**
 * Load and return the exported object from a configuration file.
 *
 * @param configPath The path to the configuration file.
 * @param project An optional path to a TypeScript configuration
 *                file.
 */
function _load(configPath, project) {
    if (project === void 0) { project = utilities_1.resolveSelf('tsconfig.json'); }
    require('ts-node').register({
        project: project,
        // Ensure that the version of TypeScript shipped with Disposition
        // is used.
        compiler: require.resolve('typescript'),
        compilerOptions: {
            // Allow compiling and running files written in JavaScript.
            allowJs: true,
        },
        ignore: ['/node_modules/'],
    });
    var config = require(configPath);
    if (config.default) {
        return config.default;
    }
    else {
        return config;
    }
}

//# sourceMappingURL=disposition.js.map
