"use strict";
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var selfDirectory = fs.realpathSync(path.join(__dirname, '..'));
/**
 * Resolve a path relative to Dispositions's package root.
 *
 * @param relativePath A path that is relative to the package root.
 * @returns The resolved path.
 */
function resolveSelf(relativePath) {
    return path.resolve(selfDirectory, relativePath);
}
exports.resolveSelf = resolveSelf;
/**
 * Search for a specific set of files by walking up the directory
 * tree.
 *
 * @param directory A directory to start from.
 * @param filenames A list of filenames to search for.
 * @returns The full path to the first file that matches one of the
 *          provided filenames.
 */
function find(directory, filenames) {
    var directoryPath = fs.realpathSync(directory);
    // Retrieve a list of the files in the current directory.
    var files = fs.readdirSync(directoryPath);
    // Iterate over the list of files and check if any match a filename
    // we are looking for.
    for (var _i = 0, files_1 = files; _i < files_1.length; _i++) {
        var file = files_1[_i];
        for (var _a = 0, filenames_1 = filenames; _a < filenames_1.length; _a++) {
            var filename = filenames_1[_a];
            if (file === filename) {
                return fs.realpathSync(path.resolve(directoryPath, file));
            }
        }
    }
    // If we have hit the top of the directory tree, return undefined.
    if (directoryPath === '/') {
        return undefined;
    }
    // If we have reached this statement, we have not found the
    // filename we are looking for in the current directory, so we run
    // the function again one directory up the tree.
    return find(path.resolve(directoryPath, '..'), filenames);
}
exports.find = find;

//# sourceMappingURL=utilities.js.map
